<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Aytias
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>
<div class="comments-wrapper default-max-width">

	<?php if ( have_comments() ) : ?>

		<div class="aytias-section-title-wrap">
			<div class="section-title">
				<h2 class="comments-title">
					<?php
					$aytias_comment_count = get_comments_number();
					if ( '1' === $aytias_comment_count ) {
						esc_html_e( '1 comment', 'aytias' ); 
					} else {
						printf(
							/* translators: %s: Comment count number. */
							esc_html( _nx( '%s comment', '%s comments', $aytias_comment_count, 'Comments title', 'aytias' ) ),
							esc_html( number_format_i18n( $aytias_comment_count ) )
						);
					}
					?>
				</h2><!-- .comments-title -->
			</div>
		</div>

		<div id="comments" class="comments comments-area">

			<?php
			wp_list_comments(
				array(
					'walker'      => new Aytias_Walker_Comment(),
					'avatar_size' => 120,
					'style'       => 'div',
				)
			);
			
			$comment_pagination = paginate_comments_links(
				array(
					'echo'      => false,
					'end_size'  => 0,
					'mid_size'  => 0,
					'next_text' => __( 'Newer Comments', 'aytias' ) . ' &rarr;',
					'prev_text' => '&larr; ' . __( 'Older Comments', 'aytias' ),
				)
			);

			if ( $comment_pagination ) :

				// If we're only showing the "Next" link, add a class indicating so
				if ( strpos( $comment_pagination, 'prev page-numbers' ) === false ) {
					$pagination_classes = ' only-next';
				} else {
					$pagination_classes = '';
				}
				?>

				<nav class="comments-pagination pagination<?php echo esc_attr( $pagination_classes ); ?>">
					<?php echo wp_kses_post( $comment_pagination ); ?>
				</nav>

			<?php endif; 

			// If comments are closed and there are comments, let's leave a little note, shall we?
			if ( ! comments_open() ) :
				?>
				<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'aytias' ); ?></p>
				<?php
			endif;

			?>

		</div><!-- #comments -->

	<?php endif; ?>

	<?php 
		comment_form(
			array(
				'title_reply_before' => '<h2 id="reply-title" class="comment-reply-title">',
				'title_reply'          => '<span>' .__('Leave a Reply', 'aytias') . '</span>',
				'title_reply_after'  => '</h2>',
			)
		);
	?>

</div>