<?php
/**
 * CSS related hooks.
 *
 * This file contains hook functions which are related to CSS.
 *
 * @package Aytias
 */

if(!function_exists('aytias_generate_font_family')):
    /**
     * Returns css apporpriate font family
     *
     * @since 1.0.0
     * 
     * @return string font-family
     */
    function aytias_generate_font_family($font_base){
        if(!empty($font_base)){
            $font_base = str_replace( '"', '', $font_base );
            $font_base_explode  = explode( ", ", $font_base );
            $font_name  = isset( $font_base_explode[0] ) ? $font_base_explode[0] : '';
            $font_serif  = isset( $font_base_explode[2] ) ? $font_base_explode[2] : '';
            $space_end   = ', ';
            if ( empty( $font_serif ) ): $space_end = ''; endif;
            return "'" . $font_name . "'" . $space_end . $font_serif;
        }
    }
endif;
 
if (!function_exists('aytias_get_inline_css')) :
    /**
     * Outputs theme custom CSS.
     *
     * @since 1.0.0
     */
    function aytias_get_inline_css(){

        $defaults = aytias_get_default_customizer_values();

        $site_title_text_size = aytias_get_option('site_title_text_size');
        $site_tagline_text_size = aytias_get_option('site_tagline_text_size');

        $primary_color = aytias_get_option('primary_color');
        $accent_color = aytias_get_option('accent_color');

        $primary_menu_text_color = aytias_get_option('primary_menu_text_color');
        $sub_menu_bg_color = aytias_get_option('sub_menu_bg_color');
        $sub_menu_text_color = aytias_get_option('sub_menu_text_color');

        $header_bg_color = aytias_get_option('header_bg_color');
        $sticky_bar_bg_color = aytias_get_option('sticky_bar_bg_color');
        $footer_bg_color = aytias_get_option('footer_bg_color');

        $primary_font = aytias_get_option('primary_font');
        $primary_font_weight = aytias_get_option('primary_font_weight') ;
        $secondary_font = aytias_get_option('secondary_font');
        $secondary_font_weight = aytias_get_option('secondary_font_weight') ;

        $top_bar_bg_color = aytias_get_option('top_bar_bg_color');
        $top_bar_date_color = aytias_get_option('top_bar_date_color');
        $top_bar_social_nav_icons_color = aytias_get_option('top_bar_social_nav_icons_color');
        $top_bar_social_nav_hover_color = aytias_get_option('top_bar_social_nav_hover_color');
        $top_bar_nav_menu_color = aytias_get_option('top_bar_nav_menu_color');
        $top_bar_nav_menu_hover_color = aytias_get_option('top_bar_nav_menu_hover_color');
        $top_bar_sub_menu_bg_color = aytias_get_option('top_bar_sub_menu_bg_color');

        ob_start();
        ?>

        <?php if( $primary_font != $defaults['primary_font'] ) : ?>
            h1,
            .heading-size-1,
            h2,
            .heading-size-2,
            h3,
            .heading-size-3,
            h4,
            .heading-size-4,
            h5,
            .heading-size-5,
            h6,
            .heading-size-6,
            input,
            textarea,
            button,
            .button,
            .wp-block-button__link,
            .wp-block-file__button {
                font-family: <?php echo sanitize_text_field( aytias_generate_font_family($primary_font) ); ?>;
            }
        <?php endif; ?>

        <?php if( $primary_font_weight != $defaults['primary_font_weight'] ) : ?>
            h1,
            .heading-size-1,
            h2,
            .heading-size-2,
            h3,
            .heading-size-3,
            h4,
            .heading-size-4,
            h5,
            .heading-size-5,
            h6,
            .heading-size-6 {
                font-weight: <?php echo esc_attr($primary_font_weight);?>
            }
        <?php endif;?>

        <?php if( $secondary_font != $defaults['secondary_font'] ) : ?>
            body, ul, ol {
                font-family: <?php echo sanitize_text_field( aytias_generate_font_family($secondary_font) ); ?>;
            }
        <?php endif; ?>

        <?php if( $secondary_font_weight != $defaults['secondary_font_weight'] ) : ?>
            body {
                font-weight: <?php echo esc_attr($secondary_font_weight);?>
            }
        <?php endif;?>

        <?php if( $site_title_text_size != $defaults['site_title_text_size'] ) : ?>
            @media (min-width: 1000px){
                .site-title {
                    font-size: <?php echo esc_attr($site_title_text_size).'px'; ?>;
                }
            }
        <?php endif; ?>

        <?php if( $site_tagline_text_size != $defaults['site_tagline_text_size'] ) : ?>
            @media (min-width: 1000px){
                .site-description {
                    font-size: <?php echo esc_attr($site_tagline_text_size).'px'; ?>;
                }
            }
        <?php endif; ?>

        <?php if( $header_bg_color !== $defaults['header_bg_color'] ):?>
            .site-header {
                background-color: <?php echo esc_attr($header_bg_color)?>;
            }
        <?php endif;?>

        <?php if( $sticky_bar_bg_color != $defaults['sticky_bar_bg_color'] ) : ?>
            .aytias-header-plus-nav.sticky-menu {
                background-color: <?php echo esc_attr($sticky_bar_bg_color)?>;
            }
        <?php endif; ?>

        <?php if( $footer_bg_color !== $defaults['footer_bg_color'] ):?>
            .site-footer {
                background-color: <?php echo esc_attr($footer_bg_color)?>;
            }
        <?php endif;?>

        <?php if( $primary_color !== $defaults['primary_color'] ): ?>
            body,
            h1 a:hover,
            h1 a:focus,
            h2 a:hover,
            h2 a:focus,
            h3 a:hover,
            h3 a:focus,
            h4 a:hover,
            h4 a:focus,
            h5 a:hover,
            h5 a:focus,
            h6 a:hover,
            h6 a:focus,
            .heading-size-1 a:hover,
            .heading-size-1 a:focus,
            .heading-size-2 a:hover,
            .heading-size-2 a:focus,
            .heading-size-3 a:hover,
            .heading-size-3 a:focus,
            .heading-size-4 a:hover,
            .heading-size-4 a:focus,
            .heading-size-5 a:hover,
            .heading-size-5 a:focus,
            .heading-size-6 a:hover,
            .heading-size-6 a:focus,
            .wp-block-code code,
            .wp-block-archives a,
            .wp-block-categories a,
            .wp-block-latest-posts a,
            .wp-block-latest-comments a,
            input,
            textarea,
            .color-primary,
            .color-primary-hover:focus,
            .color-primary-hover:hover,
            .aytias-breadcrumb-wrapper .trail-items li:not(:last-child):after,
            .widget_archive a,
            .widget_categories a,
            .widget_pages a,
            .widget_meta a,
            .widget_nav_menu a,
            .widget_recent_comments a,
            .widget_recent_entries a,
            .widget_rss a,
            .aytias-entry-meta .post-comment a,
            .aytias-entry-meta .meta-text,
            .aytias-edit a.post-edit-link {
                color: <?php echo esc_attr($primary_color)?>;
            }

            .bg-primary,
            .bg-primary-hover:focus,
            .bg-primary-hover:hover {
                background-color: <?php echo esc_attr($primary_color)?>;
            }

            .border-color-primary,
            .border-color-primary-hover:focus,
            .border-color-primary-hover:hover,
            .aytias-modal-menu li {
                border-color: <?php echo esc_attr($primary_color)?>;
            }

            .fill-children-primary,
            .fill-children-primary * {
                fill: <?php echo esc_attr($primary_color)?>;
            }

        <?php endif;?>

        <?php if( $primary_menu_text_color !== $defaults['primary_menu_text_color'] ): ?>
            .primary-menu a {
                color: <?php echo esc_attr($primary_menu_text_color);?>
            }
        <?php endif;?>
            
        <?php if( $sub_menu_bg_color !== $defaults['sub_menu_bg_color'] ): ?>

            .primary-menu ul {
                background-color: <?php echo esc_attr($sub_menu_bg_color);?>
            }

        <?php endif;?>

        <?php if( $sub_menu_text_color !== $defaults['sub_menu_text_color'] ): ?>

            .primary-menu ul {
                color: <?php echo esc_attr($sub_menu_text_color);?>
            }

        <?php endif;?>

        <?php if( $top_bar_bg_color !== $defaults['top_bar_bg_color'] ): ?>
            .aytias-topbar-row{
                background-color: <?php echo esc_attr($top_bar_bg_color);?>
            }
        <?php endif;?>

        <?php if( $top_bar_date_color !== $defaults['top_bar_date_color'] ): ?>
            .aytias-topbar-row .aytias-components-date{
                color: <?php echo esc_attr($top_bar_date_color);?>
            }
        <?php endif;?>

        <?php if( $top_bar_social_nav_icons_color !== $defaults['top_bar_social_nav_icons_color'] ): ?>
            .aytias-topbar-row .aytias-social-nav a{
                color: <?php echo esc_attr($top_bar_social_nav_icons_color);?>
            }
        <?php endif;?>

        <?php if( $top_bar_social_nav_hover_color !== $defaults['top_bar_social_nav_hover_color'] ): ?>
            .aytias-topbar-row .aytias-social-nav a:hover,
            .aytias-topbar-row .aytias-social-nav a:focus{
                color: <?php echo esc_attr($top_bar_social_nav_hover_color);?>
            }
        <?php endif;?>

        <?php if( $top_bar_nav_menu_color !== $defaults['top_bar_nav_menu_color'] ): ?>
            .aytias-topbar-row .aytias-top-nav a{
                color: <?php echo esc_attr($top_bar_nav_menu_color);?>
            }
        <?php endif;?>

        <?php if( $top_bar_nav_menu_hover_color !== $defaults['top_bar_nav_menu_hover_color'] ): ?>
            .aytias-topbar-row .aytias-top-nav a:hover,
            .aytias-topbar-row .aytias-top-nav a:focus{
                color: <?php echo esc_attr($top_bar_nav_menu_hover_color);?>
            }
        <?php endif;?>

        <?php if( $top_bar_sub_menu_bg_color !== $defaults['top_bar_sub_menu_bg_color'] ): ?>
            .aytias-top-menu .sub-menu {
                background-color: <?php echo esc_attr($top_bar_sub_menu_bg_color);?>
            }
        <?php endif;?>

        <?php if( $accent_color !== $defaults['accent_color']  ): ?>

            .wp-block-social-links
            .wp-block-social-link
            .wp-block-social-link-anchor:focus {
                border: 2px solid <?php echo esc_attr($accent_color)?>;
            }   

            a:hover,
            .color-accent,
            .color-accent-hover:focus,
            .color-accent-hover:hover,
            .aytias-entry-meta,
            .aytias-topbar-wrapper a:hover, 
            .aytias-topbar-wrapper a:focus,
            .primary-menu a:hover, 
            .primary-menu a:focus, 
            .primary-menu .current_page_ancestor,
            .wp-block-archives a:hover, 
            .wp-block-categories a:hover, 
            .wp-block-latest-posts a:hover, 
            .wp-block-latest-comments a:hover, 
            .wp-block-archives a:focus, 
            .wp-block-categories a:focus, 
            .wp-block-latest-posts a:focus, 
            .wp-block-latest-comments a:focus,
            .widget_archive a:focus, 
            .widget_archive a:hover, 
            .widget_categories a:focus, 
            .widget_categories a:hover, 
            .widget_pages a:focus, 
            .widget_pages a:hover, 
            .widget_meta a:focus, 
            .widget_meta a:hover, 
            .widget_nav_menu a:focus, 
            .widget_nav_menu a:hover, 
            .widget_recent_comments a:focus, 
            .widget_recent_comments a:hover, 
            .widget_recent_entries a:focus, 
            .widget_recent_entries a:hover, 
            .widget_rss a:focus, 
            .widget_rss a:hover,
            .aytias-breadcrumb-wrapper .trail-items a,
            .aytias-posts-lists.aytias-archive_style_4 > article a:hover {
                color: <?php echo esc_attr($accent_color)?>;
            }

            .bg-accent,
            .bg-accent-hover:focus,
            .bg-accent-hover:hover,
            .aytias-social-icons a,
            .aytias-section-title-wrap .section-title::before,
            .aytias-section-title-wrap .section-title::after,
            .comment-respond .comment-reply-title span::before,
            .comment-respond .comment-reply-title span::after,
            #aytias-scroll-to-top {
                background-color: <?php echo esc_attr($accent_color)?>;
            }

            ::-moz-selection {
                background-color: <?php echo esc_attr($accent_color)?>;
            }

            ::selection {
                background-color: <?php echo esc_attr($accent_color)?>;
            }

            .border-color-accent,
            .border-color-accent-hover:focus,
            .border-color-accent-hover:hover {
                border-color: <?php echo esc_attr($accent_color)?>;
            }

            .fill-children-accent,
            .fill-children-accent *,
            .aytias-edit.edit-link,
            .aytias-search-block .search-close {
                fill: <?php echo esc_attr($accent_color)?>;
            }

            body.single header.entry-header,
            body.page:not(.aytias-active-woocommerce-page) header.entry-header {
                border-bottom: 3px solid <?php echo esc_attr($accent_color)?>;
            }

            .aytias-search-block input:focus.search-field {
                border-bottom-color: <?php echo esc_attr($accent_color)?>;
            }

            .aytias-canvas-header {
                border-bottom: 2px solid <?php echo esc_attr($accent_color)?>;
            }

            .aytias-ajax-loader {
                border-bottom-color: <?php echo esc_attr($accent_color)?>;
            }

            #secondary .widget-area .widget:not(:last-child) {
                border-bottom: 3px solid <?php echo esc_attr($accent_color)?>;
            }

            .aytias-social-menu-widget .aytias-social-icons a:hover {
                color:#ffffff;
            }

            .aytias-social-menu-widget.style_3 .aytias-social-icons a:hover{
                color: <?php echo esc_attr($accent_color)?>;
                border-color: <?php echo esc_attr($accent_color)?>;
            }

            .aytias-author-info-widget .author-social a:hover .svg-icon {
                border-color: <?php echo esc_attr($accent_color)?>;
                fill: <?php echo esc_attr($accent_color)?>;
            }

        <?php endif;?>       

        <?php
        return ob_get_clean();
    }
endif;

if (!function_exists('aytias_get_woo_inline_css')) :
    /**
     * Outputs woocommerce custom CSS.
     *
     * @since 1.0.0
     */
    function aytias_get_woo_inline_css(){

        $defaults = aytias_get_default_customizer_values();
        $accent_color = aytias_get_option('accent_color');

        ob_start();
        ?>

        <?php if( $accent_color !== $defaults['accent_color'] ): ?>

            .woocommerce-store-notice,
            p.demo_store,
            .woocommerce span.onsale,
            .woocommerce .widget_price_filter .ui-slider .ui-slider-handle,
            .woocommerce .widget_price_filter .ui-slider .ui-slider-range,
            .woocommerce nav.woocommerce-pagination ul li a:focus,
            .woocommerce nav.woocommerce-pagination ul li a:hover,
            .woocommerce nav.woocommerce-pagination ul li span.current,
            .woocommerce div.product .woocommerce-tabs ul.tabs li.active,
            span.aytias-woo-counter,
            .wc_payment_method
                input.input-radio[name="payment_method"]:checked
                + label::before {
                background-color: <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce div.product p.price,
            .woocommerce div.product span.price,
            .woocommerce div.product .stock,
            .woocommerce ul.products li.product .price,
            #add_payment_method .cart-collaterals .cart_totals .discount td,
            .woocommerce-cart .cart-collaterals .cart_totals .discount td,
            .woocommerce-checkout .cart-collaterals .cart_totals .discount td,
            .woocommerce-message::before,
            .woocommerce-info::before,
            .woocommerce-account .woocommerce-MyAccount-navigation li.is-active a,
            .woocommerce .star-rating::before,
            .woocommerce .star-rating span::before,
            .woocommerce p.stars a {
                color: <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce table.shop_attributes,
            .woocommerce-checkout
                form
                #order_review
                .woocommerce-checkout-review-order-table
                tfoot,
            .woocommerce-checkout
                form
                #order_review_heading
                .woocommerce-checkout-review-order-table
                tfoot {
                border-top: 1px solid <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce-error,
            .woocommerce-info,
            .woocommerce-message,
            .woocommerce-account .entry-content .woocommerce {
                border-top: 3px solid <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce .widget_shopping_cart .cart_list li:not(:last-child),
            .woocommerce.widget_shopping_cart .cart_list li:not(:last-child) {
                margin-bottom: 1.2rem;
                border-bottom: 1px solid <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce-ordering .orderby:focus {
                outline: 1px solid <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce-cart-form table.shop_table thead {
                border-bottom: 2px solid <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce-cart-form table.shop_table tbody tr:last-child,
            .woocommerce-order-details .woocommerce-table tfoot {
                border-top: 2px solid <?php echo esc_attr($accent_color)?>;
            }

            .wc_payment_method input.input-radio[name="payment_method"] + label::before {
                box-shadow: 0 0 0 2px <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce .woocommerce-customer-details address {
                border: 1px solid <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce-order-details .woocommerce-table thead {
                border-bottom: 2px solid <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce form.login,
            .woocommerce form.register {
                border-color: <?php echo esc_attr($accent_color)?>;
            }

            .woocommerce div.product .woocommerce-tabs ul.tabs::before {
                border-bottom: 1px solid <?php echo esc_attr($accent_color)?>;
            }

        <?php endif;?>

        <?php
        $css = ob_get_clean();
        return $css;
    }

endif;