<?php
/**
 * Implement posts metabox.
 *
 * @package Aytias
 */

if ( ! function_exists( 'aytias_add_theme_meta_box' ) ) :

	/**
	 * Add the Meta Box
	 *
	 * @since 1.0.0
	 */
	function aytias_add_theme_meta_box() {

		$post_types = array( 'post', 'page');

		foreach ( $post_types as $post_type ) {
			add_meta_box(
				'aytias-meta-box',
                sprintf( esc_html__( '%1s Settings', 'aytias' ), ucwords($post_type) ),
				'aytias_meta_box_html',
                $post_type,
                'side'
			);
		}

	}

endif;
add_action( 'add_meta_boxes', 'aytias_add_theme_meta_box' );

if ( ! function_exists( 'aytias_meta_box_html' ) ) :

	/**
	 * Render theme settings meta box.
	 *
	 * @since 1.0.0
	 */
	function aytias_meta_box_html( $post ) {

	    global $post_type;

        wp_nonce_field( basename( __FILE__ ), 'aytias_meta_box_nonce' );
        
        $page_layout = get_post_meta($post->ID,'aytias_page_layout',true);

        $override_post_metas = get_post_meta($post->ID,'aytias_override_post_metas',true);
        $selected_postmetas = get_post_meta( $post->ID, 'aytias_single_post_metas', true ) ;

        $show_author_info = get_post_meta( $post->ID, 'aytias_show_author_info', true ) ;
        $show_related_posts = get_post_meta( $post->ID, 'aytias_show_related_posts', true ) ;
        $show_author_posts = get_post_meta( $post->ID, 'aytias_show_author_posts', true ) ;

        $layouts = aytias_get_general_layouts();
        ?>
        <div id="aytias-settings-metabox-container" class='inside be-meta-box'>
            <p><?php _e( 'Override the customizer global settings from here. Leave as it is if you want it to be same as global settings.', 'aytias' ); ?></p>
            <hr/>
            <h3><label for="page-layout"><?php  _e( 'Page Layout', 'aytias' ); ?></label></h3>
            <div class="aytias-radio-image">
                <?php
                if(!empty($layouts) && is_array($layouts)){
                    foreach ( $layouts as $value => $option ) : ?>
                        <input class="image-select" type="radio" id="<?php echo esc_attr( $value ); ?>" name="aytias_page_layout" value="<?php echo esc_attr( $value ); ?>" <?php checked( $value, $page_layout ); ?>>
                        <label for="<?php echo esc_attr( $value ); ?>">
                            <img src="<?php echo esc_html( $option['url'] ); ?>" alt="<?php echo esc_attr( $option['label'] ); ?>" title="<?php echo esc_attr( $option['label'] ); ?>">
                        </label>
                    <?php endforeach;
                }
                ?>
            </div>
            <hr/>
            <?php
            if('post' == $post_type){
                $available_post_metas = array(
                    'author' => __('Author', 'aytias'),
                    'category' => __('Category', 'aytias'),
                    'read_time' => __('Post Read Time', 'aytias'),
                    'date' => __('Date', 'aytias'),
                    'comment' => __('Comment', 'aytias'),
                    'tags' => __('Tags', 'aytias')
                );
                
                ?>
                <h3><legend><?php _e( 'Post Metas', 'aytias' ); ?></legend></h3>
                <p>
                    <input  type="checkbox" id="aytias-override-post-metas" name="aytias_override_post_metas" value="1" <?php checked( 1, $override_post_metas ); ?> />
                    <label for="aytias-override-post-metas"><?php _e('Override displayed post metas from the customizer on single post page?', 'aytias');?></label>
                </p>
                <div class="aytias-available-post-metas" <?php echo ( !$override_post_metas ? ' style="display:none"' : '' ); ?>>
                    <?php 
                    foreach ( $available_post_metas as $id => $element) {
                        if ( is_array( $selected_postmetas ) && in_array( $id, $selected_postmetas ) ) {
                            $checked = 'checked="checked"';
                        } else {
                            $checked = null;
                        }
                        ?>
                        <p>
                            <input  type="checkbox" id="<?php echo esc_attr($id);?>" name="aytias_single_post_metas[]" value="<?php echo esc_attr($id);?>" <?php echo esc_attr($checked); ?> />
                            <label for="<?php echo esc_attr($id);?>"><?php echo $element;?></label>
                        </p>
                        <?php
                    }?>
                </div>
                <h3><label for="author-info"><?php _e( 'Show Author Info', 'aytias' ); ?></label></h3>
                <div class="post-section-wrap">
                    <select id="author-info" name="aytias_show_author_info" class="widefat">
                        <option value=""><?php _e(' &mdash; Select &mdash;','aytias')?></option>
                        <option value="1" <?php selected($show_author_info, 1)?>><?php _e('Yes', 'aytias')?></option>
                        <option value="0" <?php selected($show_author_info, 0)?>><?php _e('No', 'aytias')?></option>
                    </select>
                </div>
                <hr/>
                <h3><label for="related-posts"><?php _e( 'Show Related Posts', 'aytias' ); ?></label></h3>
                <div class="post-section-wrap">
                    <select id="related-posts" name="aytias_show_related_posts" class="widefat">
                        <option value=""><?php _e(' &mdash; Select &mdash;','aytias')?></option>
                        <option value="1" <?php selected($show_related_posts, 1)?>><?php _e('Yes', 'aytias')?></option>
                        <option value="0" <?php selected($show_related_posts, 0)?>><?php _e('No', 'aytias')?></option>
                    </select>
                </div>
                <hr/>
                <h3><label for="author-posts"><?php _e( 'Show Author Posts', 'aytias' ); ?></label></h3>
                <div class="post-section-wrap">
                    <select id="author-posts" name="aytias_show_author_posts" class="widefat">
                        <option value=""><?php _e(' &mdash; Select &mdash;','aytias')?></option>
                        <option value="1" <?php selected($show_author_posts, 1)?>><?php _e('Yes', 'aytias')?></option>
                        <option value="0" <?php selected($show_author_posts, 0)?>><?php _e('No', 'aytias')?></option>
                    </select>
                </div>
                <hr/>
                <?php
            }
            ?>
        </div>
        <?php
	}

endif;


if ( ! function_exists( 'aytias_save_postdata' ) ) :

	/**
	 * Save posts meta box value.
	 *
	 * @since 1.0.0
	 *
	 * @param int  $post_id Post ID.
	 */
	function aytias_save_postdata( $post_id ) {

		// Verify nonce.
		if ( ! isset( $_POST['aytias_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['aytias_meta_box_nonce'], basename( __FILE__ ) ) ) {
			  return; }

		// Bail if auto save or revision.
		if ( defined( 'DOING_AUTOSAVE' ) || is_int( wp_is_post_revision( $post_id ) ) || is_int( wp_is_post_autosave( $post_id ) ) ) {
			return;
		}

		// Check the post being saved == the $post_id to prevent triggering this call for other save_post events.
		if ( empty( $_POST['post_ID'] ) || $_POST['post_ID'] != $post_id ) {
			return;
		}

		// Check permission.
		if ( 'page' === $_POST['post_type'] ) {
			if ( ! current_user_can( 'edit_page', $post_id ) ) {
				return;
			}
        }else if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}

        // page layout
        if ( isset( $_POST['aytias_page_layout'] )){

            $valid_layout_values = array('left-sidebar','right-sidebar','no-sidebar');
            $layout_value = sanitize_text_field( $_POST['aytias_page_layout'] );
            if( in_array( $layout_value, $valid_layout_values ) ) {
                update_post_meta($post_id, 'aytias_page_layout', $layout_value);
            }else{
                delete_post_meta($post_id,'aytias_page_layout');
            }

        }

        //post metas
        if(isset( $_POST['aytias_override_post_metas'])){
            update_post_meta($post_id, 'aytias_override_post_metas', true);
            if ( isset( $_POST['aytias_single_post_metas'] ) && !empty($_POST['aytias_single_post_metas']) ) {
                $available_post_metas = array('author','category','read_time','date','comment','tags');
                if( !array_diff($_POST['aytias_single_post_metas'], $available_post_metas) ) {
                    update_post_meta( $post_id, 'aytias_single_post_metas', $_POST['aytias_single_post_metas'] );
                }
            }else{
                delete_post_meta( $post_id, 'aytias_single_post_metas' );
            }
        }else{
            delete_post_meta($post_id, 'aytias_override_post_metas');
            delete_post_meta( $post_id, 'aytias_single_post_metas' );
        }

        //author info
        if ( isset( $_POST['aytias_show_author_info'] ) ){
            if( "1" == $_POST['aytias_show_author_info'] ){
                update_post_meta($post_id, 'aytias_show_author_info', 1);
            }elseif( "0" == $_POST['aytias_show_author_info']){
                update_post_meta($post_id, 'aytias_show_author_info', 0);
            }
            else{
                delete_post_meta($post_id, 'aytias_show_author_info');
            }
        }

        //related posts
        if ( isset( $_POST['aytias_show_related_posts'] ) ){
            if( "1" == $_POST['aytias_show_related_posts'] ){
                update_post_meta($post_id, 'aytias_show_related_posts', 1);
            }elseif( "0" == $_POST['aytias_show_related_posts']){
                update_post_meta($post_id, 'aytias_show_related_posts', 0);
            }
            else{
                delete_post_meta($post_id, 'aytias_show_related_posts');
            }
        }

         //author posts
        if ( isset( $_POST['aytias_show_author_posts'] ) ){
            if( "1" == $_POST['aytias_show_author_posts'] ){
                update_post_meta($post_id, 'aytias_show_author_posts', 1);
            }elseif( "0" == $_POST['aytias_show_author_posts']){
                update_post_meta($post_id, 'aytias_show_author_posts', 0);
            }
            else{
                delete_post_meta($post_id, 'aytias_show_author_posts');
            }
        }

	}

endif;
add_action( 'save_post', 'aytias_save_postdata' );

if(!function_exists('aytias_post_meta_admin_scripts')):
    /**
     * Styles and Scripts for meta box
     *
     * @since 1.0.0
     *
     */
    function aytias_post_meta_admin_scripts($hook) {
        global $post_type;

        if($hook != 'post-new.php' && $hook != 'post.php') {
            return;
        }
        if($post_type != 'post' && $post_type != 'page'){
            return;
        }

        wp_enqueue_script( 'aytias-post-meta-js', get_template_directory_uri().'/inc/post-meta/js/script.js', array(), '1.0', true );
    }
endif;
add_action( 'admin_enqueue_scripts', 'aytias_post_meta_admin_scripts' );