<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Aytias
 */

if ( ! function_exists( 'aytias_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function aytias_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( 'Posted on %s', 'post date', 'aytias' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;

if ( ! function_exists( 'aytias_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function aytias_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'aytias' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;

if ( ! function_exists( 'aytias_get_single_post_metas' ) ) :
	/**
	 * Get allowed single post meta based on post meta/customizer
	 */
	function aytias_get_single_post_metas($post_id) {
		// Check if the metas are overridden in post meta
		$override_post_metas = get_post_meta($post_id, 'aytias_override_post_metas', true );
		if($override_post_metas){
			$enabled_post_meta = get_post_meta($post_id, 'aytias_single_post_metas', true );
		}else{
			$enabled_post_meta = aytias_get_option('single_post_meta');
		}
		// Return an empty array if all options are unchecked
		if($enabled_post_meta){
			return $enabled_post_meta;
		}else{
			return array();
		}
	}
endif;

if ( ! function_exists( 'aytias_show_author_info' ) ) :
	/**
	 * Get if author info is enabled based on post meta/customizer
	 */
	function aytias_show_author_info($post_id) {
		$show_author_info = get_post_meta($post_id, 'aytias_show_author_info', true );
		if( "0" == $show_author_info ){
			$show_author_info = false;
		}elseif( "1" == $show_author_info ){
			$show_author_info = true;
		}else{
			$show_author_info = aytias_get_option('show_author_info');
		}
		return $show_author_info;
	}
endif;

if ( ! function_exists( 'aytias_show_related_posts' ) ) :
	/**
	 * Get if related posts are enabled based on post meta/customizer
	 */
	function aytias_show_related_posts($post_id) {
		$show_related_posts = get_post_meta($post_id, 'aytias_show_related_posts', true );
		if( "0" == $show_related_posts ){
			$show_related_posts = false;
		}elseif( "1" == $show_related_posts ){
			$show_related_posts = true;
		}else{
			$show_related_posts = aytias_get_option('show_related_posts');
		}
		return $show_related_posts;
	}
endif;

if ( ! function_exists( 'aytias_show_author_posts' ) ) :
	/**
	 * Get if author posts are enabled based on post meta/customizer
	 */
	function aytias_show_author_posts($post_id) {
		$show_author_posts = get_post_meta($post_id, 'aytias_show_author_posts', true );
		if( "0" == $show_author_posts ){
			$show_author_posts = false;
		}elseif( "1" == $show_author_posts ){
			$show_author_posts = true;
		}else{
			$show_author_posts = aytias_get_option('show_author_posts');
		}
		return $show_author_posts;
	}
endif;

if ( ! function_exists( 'aytias_post_meta_info' ) ) :
    /**
     * Display post meta info.
     *
     * @param boolean $author Show author
	 * @param boolean $comment Show read time
     * @param boolean $date Show date
     *
     * @since 1.0.0
     */
    function aytias_post_meta_info( $enabled_post_meta = array() ) {
        ?>
        <ul class="aytias-entry-meta">
            <?php
			// Author
            if( in_array('author', $enabled_post_meta) ){
                ?>
                <li class="aytias-meta post-author">
					<span class="meta-icon">
						<span class="screen-reader-text"><?php _e( 'Post Author', 'aytias' ); ?></span>
						<?php aytias_the_theme_svg('user'); ?>
					</span>
					<span class="meta-text">
						<?php
							printf(
								/* translators: %s: Author name. */
								__( 'By %s', 'aytias' ),
								'<a href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author_meta( 'display_name' ) ) . '</a>'
							);
							?>
					</span>
                </li>
                <?php
            }

			// Read time
			if( in_array('read_time', $enabled_post_meta) ){
				?>
				<li class="aytias-meta post-read-time">
					<span class="meta-icon">
						<span class="screen-reader-text"><?php _e( 'Estimated read time', 'aytias' ); ?></span>
						<?php aytias_the_theme_svg('time'); ?>
					</span>
					<span class="meta-text">
						<?php
						$read_time = aytias_estimated_read_time(get_the_content());
						echo sprintf(__("%s min read", 'aytias'), number_format_i18n($read_time));
						?>
					</span>
				</li>
				<?php
			}

			// Date
            if(in_array('date', $enabled_post_meta)){
                ?>
                <li class="aytias-meta post-date">
                    <span class="meta-icon">
						<span class="screen-reader-text"><?php _e( 'Post Date', 'aytias' ); ?></span>
                        <?php aytias_the_theme_svg('calendar'); ?>
                    </span>
                    <span class="meta-text">
                        <?php echo esc_html(get_the_date()); ?>
                    </span>
                </li>
                <?php
            }

			// Comment
            if ( in_array('comment', $enabled_post_meta) ) {
                if ( !post_password_required() && (comments_open() || get_comments_number()) ) {
                    ?>
                    <li class="aytias-meta post-comment">
                        <?php
                        $number = get_comments_number(get_the_ID());
                        if (0 == $number) {
                            $respond_link = get_permalink() . '#respond';
                            $comment_link = apply_filters('respond_link', $respond_link, get_the_ID());
                        } else {
                            $comment_link = get_comments_link();
                        }
                        ?>
						<span class="meta-icon">
							<span class="screen-reader-text"><?php _e( 'Post Comment', 'aytias' ); ?></span>
							<?php aytias_the_theme_svg('comment'); ?>
						</span>
						<span class="meta-text">
							<a href="<?php echo esc_url($comment_link) ?>">
								<?php 
								if ( '1' === $number ) {
									esc_html_e( '1 comment', 'aytias' ); 
								} else {
									printf(
										/* translators: %s: Comment count number. */
										esc_html( _nx( '%s comment', '%s comments', $number, 'Comments title', 'aytias' ) ),
										esc_html( number_format_i18n( $number ) )
									);
								}
								?>
							</a>
						</span>
                    </li>
                    <?php
                }
            }
            ?>

        </ul>
        <?php
    }
endif;

if ( ! function_exists( 'aytias_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function aytias_entry_footer() {


		// Hide tag text for pages.
		if ( 'post' === get_post_type() ) {

			if(is_single()){
				$enabled_post_meta = aytias_get_option('single_post_meta');
			}else{
				$enabled_post_meta = aytias_get_option('archive_post_meta');
			}

			if(in_array('tags', $enabled_post_meta)){
				the_tags( '<span class="tags-links"><ul class="tag-lists reset-list-style"><li>', '</li><li>', '</li></ul></span>' );
			}
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'aytias' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				wp_kses_post( get_the_title() )
			),
			'<span class="aytias-edit edit-link">'.aytias_get_theme_svg( 'edit' ),
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'aytias_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function aytias_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

			<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php
					the_post_thumbnail(
						'post-thumbnail',
						array(
							'alt' => the_title_attribute(
								array(
									'echo' => false,
								)
							),
						)
					);
				?>
			</a>

			<?php
		endif; // End is_singular().
	}
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;

/**
 * Adds a Sub Nav Toggle to Menu
 *
 * @since Aytias 1.0
 *
 * @param stdClass $args  An object of wp_nav_menu() arguments.
 * @param WP_Post  $item  Menu item data object.
 * @param int      $depth Depth of menu item. Used for padding.
 * @return stdClass An object of wp_nav_menu() arguments.
 */
function aytias_add_sub_toggles_to_main_menu( $args, $item, $depth ) {
	

	if ( 'primary-menu' === $args->theme_location && ( isset( $args->show_toggles ) && $args->show_toggles ) ) {

		// Wrap the menu item link contents in a div, used for positioning.
		$args->before = '<div class="ancestor-wrapper">';
		$args->after  = '';

		// Add a toggle to items with children.
		if ( in_array( 'menu-item-has-children', $item->classes, true ) ) {

			$toggle_target_string = '.aytias-modal-menu .menu-item-' . $item->ID . ' > .sub-menu';

			// Add the sub menu toggle.
			$args->after .= '<button class="toggle sub-menu-toggle fill-children-current-color" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="screen-reader-text">' . __( 'Show sub menu', 'aytias' ) . '</span>' . aytias_get_theme_svg( 'chevron-down' ) . '</button>';

		}

		// Close the wrapper.
		$args->after .= '</div><!-- .ancestor-wrapper -->';

		// Add sub menu icons to the primary menu without toggles.
	} elseif ( 'primary-menu' === $args->theme_location ) {
		if ( in_array( 'menu-item-has-children', $item->classes, true ) ) {
			$args->link_after = '<span class="icon">'.aytias_get_theme_svg( 'chevron-down' ).'</span>';
		} else {
			$args->link_after = '';
		}
	}

	return $args;

}
add_filter( 'nav_menu_item_args', 'aytias_add_sub_toggles_to_main_menu', 10, 3 );

/**
 * Displays SVG icons in social links menu.
 *
 * @since Aytias 1.0
 *
 * @param string   $item_output The menu item's starting HTML output.
 * @param WP_Post  $item        Menu item data object.
 * @param int      $depth       Depth of the menu. Used for padding.
 * @param stdClass $args        An object of wp_nav_menu() arguments.
 * @return string The menu item output with social icon.
 */
function aytias_nav_menu_social_icons( $item_output, $item, $depth, $args ) {
	// Change SVG icon inside social links menu if there is supported URL.
	if ( 'social-menu' === $args->theme_location ) {
		$svg = Aytias_SVG_Icons::get_social_link_svg( $item->url );
		if ( empty( $svg ) ) {
			$svg = aytias_get_theme_svg( 'link' );
		}
		$item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
	}
	return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'aytias_nav_menu_social_icons', 10, 4 );

/**
 * Checks if the specified comment is written by the author of the post commented on.
 *
 * @since Aytias 1.0
 *
 * @param object $comment Comment data.
 * @return bool
 */
function aytias_is_comment_by_post_author( $comment = null ) {

	if ( is_object( $comment ) && $comment->user_id > 0 ) {

		$user = get_userdata( $comment->user_id );
		$post = get_post( $comment->comment_post_ID );

		if ( ! empty( $user ) && ! empty( $post ) ) {

			return $comment->user_id === $post->post_author;

		}
	}
	return false;

}