<?php

if (!defined('ABSPATH')) {
    exit;
}

class Aytias_Call_To_Action extends Aytias_Widget_Base
{
    /**
     * Constructor.
     */
    public function __construct()
    {
        $this->widget_cssclass = 'widget_aytias_call_to_action';
        $this->widget_description = __("Adds Call to action section", 'aytias');
        $this->widget_id = 'aytias_call_to_action';
        $this->widget_name = __('Aytias: Call To Action', 'aytias');

        $this->settings = array(
            'title' => array(
                'type' => 'text',
                'label' => __('Widget Title', 'aytias'),
            ),
            'title_text' => array(
                'type' => 'text',
                'label' => __('CTA Title', 'aytias'),
            ),
            'desc'  => array(
                'type'  => 'textarea',
                'label' => __( 'CTA Description', 'aytias' ),
                'rows' => 10,
            ),
            'bg_image'  => array(
                'type'  => 'image',
                'label' => __( 'Background Image', 'aytias' ),
            ),
            'btn_text'  => array(
                'type'  => 'text',
                'label' => __( 'Button Text', 'aytias' ),
            ),
            'btn_link'  => array(
                'type'  => 'url',
                'label' => __( 'Link to url', 'aytias' ),
                'desc' => __( 'Enter a proper url with http: OR https:', 'aytias' ),
            ),
            'link_target'  => array(
                'type'  => 'checkbox',
                'label' => __( 'Open Link in new Tab', 'aytias' ),
                'std' => true,
            ),
            'msg' => array(
                'type' => 'message',
                'label' => __('Additonal Settings', 'aytias'),
            ),
            'enable_fixed_bg'  => array(
                'type'  => 'checkbox',
                'label' => __( 'Enable Fixed Background Image', 'aytias' ),
                'std' => true,
            ),
            'bg_overlay_color' => array(
                'type' => 'color',
                'label' => __( 'Overlay Color', 'aytias' ),
                'std' => '#000000',
            ),
            'overlay_opacity'  => array(
                'type' => 'number',
                'step' => 10,
                'min' => 0,
                'max' => 100,
                'std' => 50,
                'label' => __('Overlay Opacity (Default 50%)', 'aytias'),
            ),
        );

        parent::__construct();
    }

    /**
     * Output widget.
     *
     * @see WP_Widget
     *
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        ob_start();

        $this->widget_start($args, $instance);

        do_action( 'aytias_before_cta');

        ?>

        <?php if( $instance['bg_image'] && 0!= $instance['bg_image']) :?>

            <?php 
            $style = 'background-color:'.$instance['bg_overlay_color'].';';  
            $style .= 'opacity:'.($instance['overlay_opacity']/100).';';
            ?>

            <div class="aytias-cta-widget aytias-cover-block<?php echo ($instance['enable_fixed_bg']) ? ' aytias-bg-image aytias-bg-attachment-fixed' : '';?>">

                <span aria-hidden="true" class="aytias-block-overlay" style="<?php echo esc_attr($style);?>"></span>

                <?php echo wp_get_attachment_image($instance['bg_image'],'full');?>

                <div class="aytias-cta-inner-wrapper aytias-block-inner-wrapper">

                    <?php if ($instance['title_text']) : ?>
                        <div class="cta-title">
                            <?php echo esc_html($instance['title_text']); ?>
                        </div>
                    <?php endif;?>

                    <?php if ($instance['desc']) : ?>
                        <div class="cta-description">
                            <?php echo wpautop(wp_kses_post($instance['desc'])); ?>
                        </div>
                    <?php endif;?>

                    <?php if ($instance['btn_text']) : ?>
                        <div class="cta-button">
                            <a 
                            href="<?php echo ($instance['btn_link']) ? esc_url($instance['btn_link']): '';?>" 
                            target="<?php echo ($instance['link_target']) ? "_blank": '_self';?>" class="button"><?php echo esc_html(($instance['btn_text']));?></a>
                        </div>
                    <?php endif; ?>

                </div>

            </div>
            
        <?php endif;?>

        <?php

        do_action( 'aytias_after_cta');

        $this->widget_end($args);

        echo ob_get_clean();
    }

}