<?php

if (!defined('ABSPATH')) {
    exit;
}

class Aytias_Social_Menu extends Aytias_Widget_Base
{

    /**
     * Constructor.
     */
    public function __construct()
    {
        $this->widget_cssclass = 'widget_aytias_social_menu';
        $this->widget_description = __("Displays social menu if you have set it.", 'aytias');
        $this->widget_id = 'aytias_social_menu';
        $this->widget_name = __('Aytias: Social Menu', 'aytias');
        $this->settings = array(
            'title' => array(
                'type' => 'text',
                'label' => __('Title', 'aytias'),
            ),
            'style' => array(
                'type' => 'select',
                'label' => __('Style', 'aytias'),
                'options' => array(
                    'style_1' => __('Style 1', 'aytias'),
                    'style_2' => __('Style 2', 'aytias'),
                    'style_3' => __('Style 3', 'aytias'),
                ),
                'std' => 'style_1',
            ),
        );

        parent::__construct();
    }

    /**
     * Output widget.
     *
     * @see WP_Widget
     *
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        ob_start();

        $this->widget_start($args, $instance);

        do_action( 'aytias_before_social_menu');

        $style = $instance['style'];

        ?>
        <div class="aytias-social-menu-widget <?php echo esc_attr($style);?>">
            <?php

            if ( has_nav_menu( 'social-menu' ) ) {
                wp_nav_menu(array(
                    'theme_location' => 'social-menu',
                    'container_class' => 'footer-navigation',
                    'fallback_cb' => false,
                    'depth' => 1,
                    'menu_class' => 'aytias-social-icons reset-list-style fill-children-current-color',
                    'link_before' => '<span class="screen-reader-text">',
                    'link_after' => '</span>',
                ) );
            }else{
                esc_html_e( 'Social menu is not set. You need to create menu and assign it to Social Menu on Menu Settings.', 'aytias' );
            }
            ?>
        </div>
        <?php

        do_action( 'aytias_after_social_menu');

        $this->widget_end($args);

        echo ob_get_clean();
    }
}