<?php
/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function aytias_widgets_init() {
    $sidebar_args['sidebar'] = array(
        'name'          => __( 'Sidebar', 'aytias' ),
        'id'            => 'sidebar-1',
        'description'   => ''
    );

    $sidebar_args['offcanvas_sidebar_before_menu'] = array(
        'name'        => __( 'Offcanvas Sidebar Before Menu', 'aytias' ),
        'id'          => 'offcanvas-sidebar-before-menu',
        'description' => __( 'Widgets added to this region will appear in the offcanvas sidebar before menu item.', 'aytias' ),
    );

    $sidebar_args['offcanvas_sidebar_after_menu'] = array(
        'name'        => __( 'Offcanvas Sidebar After Menu', 'aytias' ),
        'id'          => 'offcanvas-sidebar-after-menu',
        'description' => __( 'Widgets added to this region will appear in the offcanvas sidebar after menu item.', 'aytias' ),
    );

    /*Get homepage sidebar option from the customizer*/
    $front_page_enable_sidebar = aytias_get_option('front_page_enable_sidebar');
    if($front_page_enable_sidebar){
        $sidebar_args['homepage_sidebar'] = array(
            'name'        => __( 'Homepage Sidebar', 'aytias' ),
            'id'          => 'home-page-sidebar',
            'description' => __( 'Widgets added to this region will appear on the homepage sidebar.', 'aytias' ),
        );
    }

    $sidebar_args['above_footer'] = array(
        'name'        => __( 'Above Footer', 'aytias' ),
        'id'          => 'before-footer-widgetarea',
        'description' => __( 'Widgets added to this region will appear above the footer.', 'aytias' ),
    );

    $sidebar_args['above_footer_no_container'] = array(
        'name'        => __( 'Above Footer - No Container', 'aytias' ),
        'id'          => 'before-footer-widgetarea-nc',
        'description' => __( 'Same as above footer but does not have its own container.', 'aytias' ),
    );

    /*Get the footer column from the customizer*/
    $footer_column_layout = aytias_get_option('footer_column_layout');
    if($footer_column_layout){
        switch ($footer_column_layout) {
            case "footer_layout_1":
                $footer_column = 4;
                break;
            case "footer_layout_2":
            case "footer_layout_5":
                $footer_column = 3;
                break;
            case "footer_layout_3":
            case "footer_layout_4":
            case "footer_layout_6":
                $footer_column = 2;
                break;
            default:
                $footer_column = 4;
        }
    }else{
        $footer_column = 4;
    }

    $cols = intval( apply_filters( 'aytias_footer_widget_columns', $footer_column ) );

    for ( $j = 1; $j <= $cols; $j++ ) {
        $footer   = sprintf( 'footer_%d', $j );

        $footer_region_name = sprintf( __( 'Footer Column %1$d', 'aytias' ), $j );
        $footer_region_description = sprintf( __( 'Widgets added here will appear in column %1$d of the footer.', 'aytias' ), $j );

        $sidebar_args[ $footer ] = array(
            'name'        => $footer_region_name,
            'id'          => sprintf( 'footer-%d', $j ),
            'description' => $footer_region_description,
        );
    }

    $sidebar_args['below_footer'] = array(
        'name'        => __( 'Below Footer', 'aytias' ),
        'id'          => 'after-footer-widgetarea',
        'description' => __( 'Widgets added to this region will appear after the footer and before sub-footer.', 'aytias' ),
    );

    $sidebar_args['below_footer_no_container'] = array(
        'name'        => __( 'Below Footer - No Container', 'aytias' ),
        'id'          => 'after-footer-widgetarea-nc',
        'description' => __( 'Same as below footer but does not have its own container.', 'aytias' ),
    );

    $sidebar_args = apply_filters( 'aytias_sidebar_args', $sidebar_args );

    foreach ( $sidebar_args as $sidebar => $args ) {
        $widget_tags = array(
            'before_widget' => '<div id="%1$s" class="widget aytias-widget %2$s"><div class="widget-content">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h2 class="widget-title">',
            'after_title'   => '</h2>',
        );

        /**
         * Dynamically generated filter hooks. Allow changing widget wrapper and title tags. See example below.
         */
        $filter_hook = sprintf( 'aytias_%s_widget_tags', $sidebar );
        $widget_tags = apply_filters( $filter_hook, $widget_tags );

        if ( is_array( $widget_tags ) ) {
            register_sidebar( $args + $widget_tags );
        }
    }
}
add_action( 'widgets_init', 'aytias_widgets_init' );