<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Aytias
 */

get_header();

// Add a main container in case if sidebar is present
$class = '';
$page_layout = aytias_get_page_layout();
if('no-sidebar' != $page_layout){
	$class = 'wide-max-width';
}
/*Set the query var to use proper template file */
$archive_style = aytias_get_option('archive_style');
if(empty($archive_style)){
	$archive_style = 'archive_style_1';
}
set_query_var( 'archive_style', $archive_style );

?>
<main id="site-content" role="main" class="wrapper <?php echo esc_attr($class);?>">
	
	<div id="primary" class="content-area" data-template="<?php echo esc_attr($archive_style);?>">

		<?php get_template_part( 'template-parts/header/breadcrumb' ); ?>

		<?php
		if ( have_posts() ) :

			if ( is_home() && ! is_front_page() ) :
				?>
				<header>
					<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
				</header>
				<?php
			endif;

			echo '<div id="aytias-post-lists-wrapper" class="aytias-posts-lists aytias-'.esc_attr($archive_style). '">';

			/* Start the Loop */
			while ( have_posts() ) : the_post();
				
				get_template_part('template-parts/content/content', 'archive');

			endwhile;

			echo '</div><!-- .aytias-posts-lists -->';

			get_template_part( 'template-parts/pagination' );

		else :

			get_template_part( 'template-parts/content/content', 'none' );

		endif;
		?>

	</div> <!-- #primary -->

	<?php 
	if('no-sidebar' != $page_layout){
		get_sidebar();
	}
	?>
	
</main> <!-- #site-content-->
<?php
get_footer();