<?php
/**
 * The template for displaying search results pages
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#search-result
 *
 * @package Aytias
 */

get_header();

global $wp_query;

$archive_title = sprintf(
	'%1$s %2$s',
	'<span class="color-accent">' . __( 'Search:', 'aytias' ) . '</span>',
	'&ldquo;' . get_search_query() . '&rdquo;'
);

if ( $wp_query->found_posts ) {
	$archive_subtitle = sprintf(
		/* translators: %s: Number of search results. */
		_n(
			'%s result for your search.',
			'%s results for your search.',
			$wp_query->found_posts,
			'aytias'
		),
		number_format_i18n( $wp_query->found_posts )
	);
} else {
	$archive_subtitle = __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'aytias' );
}
?>

<main id="site-content" role="main" class="wrapper wide-max-width">

	<div id="primary" class="content-area" data-template="archive_style_1">

	<?php get_template_part( 'template-parts/header/breadcrumb' ); ?>

			<?php if ( have_posts() ) : ?>

				<header class="page-header wide-max-width">
					<div class="archive-header-content-wrap">
						<h1 class="archive-title">
							<?php echo wp_kses_post( $archive_title ); ?>
						</h1>
						<div class="archive-subtitle"><?php echo wp_kses_post( wpautop( $archive_subtitle ) ); ?></div>
					</div>
				</header><!-- .page-header -->

				<?php

				echo '<div class="aytias-posts-lists">';

				/* Start the Loop */
				while ( have_posts() ) :
					the_post();

					/**
					 * Run the loop for the search to output the results.
					 * If you want to overload this in a child theme then include a file
					 * called content-search.php and that will be used instead.
					 */
					get_template_part( 'template-parts/content/content', 'search' );

				endwhile;

				echo '</div><!-- .aytias-posts-lists -->';

				get_template_part( 'template-parts/pagination' );

			else :

				?>
				<header class="page-header">
					<div class="archive-header-content-wrap">
						<h1 class="archive-title">
							<?php echo wp_kses_post( $archive_title ); ?>
						</h1>
						<div class="archive-subtitle"><?php echo wp_kses_post( wpautop( $archive_subtitle ) ); ?></div>
					</div>
				</header><!-- .page-header -->

				<div class="no-search-results-form">
					<?php
					get_search_form(
						array(
							'aria_label' => __( 'search again', 'aytias' ),
						)
					);
					?>
				</div><!-- .no-search-results -->
				
				<?php

			endif;
			?>
	</div> <!-- #primary -->

	<?php 
	$page_layout = aytias_get_page_layout();
	if('no-sidebar' != $page_layout):
		get_sidebar(); 
	endif;
	?>

</main> <!-- #site-content -->

<?php
get_footer();