<?php
/**
 * The template for displaying all single posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Aytias
 */

get_header();

// Set some query vars to be used on templates
global $post;
$single_post_style = get_post_meta($post->ID, 'aytias_single_post_style', true );
if(empty($single_post_style)){
    $single_post_style = aytias_get_option('single_post_style');
}
set_query_var( 'single_post_style', $single_post_style );

$enabled_post_meta = aytias_get_single_post_metas($post->ID);
set_query_var( 'enabled_post_meta', $enabled_post_meta );

// Add some wrapper classes
$class = '';
$page_layout = aytias_get_page_layout();
if('no-sidebar' != $page_layout){
	$class = 'wide-max-width';
}
set_query_var( 'page_layout', $page_layout );
?>
<main id="site-content" role="main" class="wrapper <?php echo esc_attr($class);?>">

	<div id="primary" class="content-area <?php echo esc_attr($single_post_style);?>">

		<?php get_template_part( 'template-parts/header/breadcrumb' ); ?>

		<?php
		while ( have_posts() ) :
			the_post();

			get_template_part( 'template-parts/content/content', get_post_type() );

			get_template_part('template-parts/navigation');

			if ( 'post' === get_post_type() ) :

				// Get Author Info & related/Author posts
				$show_author_info = aytias_show_author_info(get_the_ID());
				$show_related_posts = aytias_show_related_posts(get_the_ID());
				$show_author_posts = aytias_show_author_posts(get_the_ID());

				if( $show_author_info ):
					get_template_part('template-parts/single/author-info');
				endif;

				if( $show_related_posts ):
					get_template_part('template-parts/single/related-posts');
				endif;

				if( $show_author_posts ):
					get_template_part('template-parts/single/author-posts');
				endif;

			endif;

			// If comments are open or we have at least one comment, load up the comment template.
			if ( comments_open() || get_comments_number() ) :
				comments_template();
			endif;

		endwhile; // End of the loop.
		?>
	</div><!--  #primary -->

	<?php 
	$page_layout = aytias_get_page_layout();
	if('no-sidebar' != $page_layout):
		get_sidebar(); 
	endif;
	?>
	
</main> <!-- #site-content -->
<?php
get_footer();