<?php
/**
 * Displays the next and previous post navigation in single posts.
 *
 * @package WordPress
 * @subpackage Aytias
 */

$next_post = get_next_post();
$prev_post = get_previous_post();

if ( $next_post || $prev_post ) :

	$pagination_classes = '';

	if ( ! $next_post ) {
		$pagination_classes = ' only-one only-prev';
	} elseif ( ! $prev_post ) {
		$pagination_classes = ' only-one only-next';
	}

	$posts_navigation_style = aytias_get_option('posts_navigation_style');

	if('style_1' == $posts_navigation_style ):
		?>
		<nav class="navigation post-navigation<?php echo esc_attr( $pagination_classes ); ?>" aria-label="<?php esc_attr_e( 'Post', 'aytias' ); ?>">
			<div class="aytias-pagination-single nav-links">
				<?php if ( $prev_post ) : ?>
					<a class="nav-previous" href="<?php echo esc_url( get_permalink( $prev_post->ID ) ); ?>">
						<span class="arrow" aria-hidden="true">&larr;</span>
						<span class="title"><span class="title-inner"><?php echo wp_kses_post( get_the_title( $prev_post->ID ) ); ?></span></span>
					</a>
				<?php endif; ?>
	
				<?php if ( $next_post ) :?>
					<a class="nav-next" href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>">
						<span class="arrow" aria-hidden="true">&rarr;</span>
						<span class="title"><span class="title-inner"><?php echo wp_kses_post( get_the_title( $next_post->ID ) ); ?></span></span>
					</a>
				<?php endif;?>
			</div><!-- .aytias-pagination-single -->
		</nav><!-- .post-navigation -->
	<?php 
	else: 
		$prev_thumb = $next_thumb = '';
		if ( is_attachment() && 'attachment' == $prev_post->post_type ) {
			return;
		}

		if ( $prev_post &&  has_post_thumbnail( $prev_post->ID ) ) {
			$prev_thumb = '<span class="post-thumb">'.get_the_post_thumbnail($prev_post->ID, 'thumbnail').'</span>';
		}

		if ( $next_post && has_post_thumbnail( $next_post->ID ) ) {
			$next_thumb = '<span class="post-thumb">'.get_the_post_thumbnail($next_post->ID, 'thumbnail').'</span>';
		}
		?>
		<nav class="navigation post-navigation<?php echo esc_attr( $pagination_classes ); ?>" aria-label="<?php esc_attr_e( 'Post', 'aytias' ); ?>">
			<div class="aytias-pagination-single style-2 nav-links">
				<?php if ( $prev_post ) : ?>
					<a class="nav-previous" href="<?php echo esc_url( get_permalink( $prev_post->ID ) ); ?>">
						<?php echo $prev_thumb;?>
						<span class="post-info">
							<span class="meta-nav" aria-hidden="true"><?php _e('Previous Article', 'aytias')?></span> 
							<span class="screen-reader-text"><?php _e('Previous Post:', 'aytias')?></span> 
							<span class="title"><span class="title-inner"><?php echo wp_kses_post( get_the_title( $prev_post->ID ) ); ?></span></span>
						</span>
					</a>
				<?php endif; ?>
	
				<?php if ( $next_post ) :?>
					<a class="nav-next" href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>">
						<?php echo $next_thumb;?>
						<span class="post-info">
							<span class="meta-nav" aria-hidden="true"><?php _e('Next Article', 'aytias')?></span> 
							<span class="screen-reader-text"><?php _e('Next Post:', 'aytias')?></span> 
							<span class="title"><span class="title-inner"><?php echo wp_kses_post( get_the_title( $next_post->ID ) ); ?></span></span>
						</span>
					</a>
				<?php endif;?>
			</div><!-- .aytias-pagination-single -->
		</nav><!-- .post-navigation -->
		<?php
	endif;
endif;